![qualified](https://raw.github.com/timothycrosley/qualified/develop/artwork/logo.png)
===================

[![PyPI version](https://badge.fury.io/py/qualified.svg)](http://badge.fury.io/py/qualified)
[![Build Status](https://travis-ci.org/timothycrosley/qualified.svg?branch=master)](https://travis-ci.org/timothycrosley/qualified)
[![Coverage Status](https://coveralls.io/repos/timothycrosley/qualified/badge.svg?branch=master&service=github)](https://coveralls.io/github/timothycrosley/qualified?branch=master)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/qualified/)
[![Join the chat at https://gitter.im/timothycrosley/qualified](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/timothycrosley/qualified?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

For when invalid data is the default

[![qualified Example](https://raw.github.com/timothycrosley/qualified/develop/artwork/example.gif)](https://github.com/timothycrosley/qualified/blob/develop/examples/example.py)


Installing qualified
===================

Installing qualified is as simple as:

```bash
pip3 install qualified --upgrade
```

Ideally, within a virtual environment.


Why qualified?
===================

For when invalid data is the default

--------------------------------------------

Thanks and I hope you find qualified helpful!

~Timothy Crosley
